@@ -1,4 +1,4 @@
-# $Id: Directory.pm 42646 2014-12-02 15:49:50Z anton $
+# $Id: Directory.pm 43381 2015-05-28 16:52:16Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -323,6 +323,7 @@ sub verify_password {
 	return $err;
 }
 
+
 sub getAccount {
 	my $uid = shift;
 	my ($entry, $err) = $self->ldap_search_uid($uid);
@@ -502,4 +503,14 @@ sub resetPasswordExpirationStatus {
 	}
 }
 
+sub removeEnclosingBrackets {
+	my $_ = shift;
+
+	while (/^\(/ and /\)$/){
+		s/^\(//;
+		s/\)$//;
+	}
+	$_;
+}
+
 0;
